#ifndef EL__ECMASCRIPT_QUICKJS_NAVIGATOR_H
#define EL__ECMASCRIPT_QUICKJS_NAVIGATOR_H

#include <quickjs/quickjs.h>

#ifdef __cplusplus
extern "C" {
#endif

int js_navigator_init(JSContext *ctx);

#ifdef __cplusplus
}
#endif

#endif
